# AutoSys

---

[![Build Status](https://travis-ci.com/skeptycal/autosys.svg?branch=master)](https://travis-ci.com/skeptycal/autosys)

![https://pypi.python.org/pypi/autosys](http://img.shields.io/pypi/v/autosys.svg?style=flat)

![https://pypi.python.org/pypi/autosys](https://img.shields.io/pypi/pyversions/autosys.svg)

![https://pypi.python.org/pypi/autosys](https://img.shields.io/pypi/implementation/autosys.svg)

![https://pypi.python.org/pypi/autosys](https://img.shields.io/pypi/wheel/autosys.svg)

![https://pypi.python.org/pypi/autosys](https://img.shields.io/badge/test_coverage-100%25-6600CC.svg)

![https://pypi.python.org/pypi/autosys](https://img.shields.io/badge/branch_coverage-100%25-6600CC.svg)

# Getting Started

## Prerequisites

Autosys requires the following modules.

- Python 3.6+
- requests
- pyyaml (for optional YAML serialization)
- ujson (for optional JSON speedups)
- numpy (for optional numpy derivatives)

## Installing

## Running the tests


## Break down into end to end tests

## Coding style tests

Pylint and Autopep8 are used to enforce coding conventions.

## Deployment

## Built With

## Contributing

Please read CONTRIBUTING.md for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use SemVer for versioning. For the versions available, see the tags on this repository.

## Contributors
- [Michael Treanor](https://www.twitter.com/skeptycal) - Initial work
- Sarah Treanor - art and design inspiration
- [Sarah Drasner](https://sarahdrasnerdesign.com/) - advice and motivation

See also the list of contributors who participated in this project.

## License

This project is licensed under the MIT License - see the LICENSE file for details

## System utilities for Python on macOS

- Setup and maintain python repos automatically

### Example Usage



### More Examples



### Utility Functions



### License

`AutoSys` is licensed under the `MIT <https://opensource.org/licenses/MIT>`.
